summaryrefslogtreecommitdiff
path: root/Master/setuptl/tlpm-i386-linux.pl
diff options
context:
space:
mode:
authorStaszek Wawrykiewicz <staw@gust.org.pl>2007-01-22 23:52:20 +0000
committerStaszek Wawrykiewicz <staw@gust.org.pl>2007-01-22 23:52:20 +0000
commit8027c99f372cc214604cb68dc9ed0e2643a634a0 (patch)
tree85bb0ae0c7326f653fd0ec2a8877204b6dc5dfd7 /Master/setuptl/tlpm-i386-linux.pl
parente1a058df6a05c82f595065a81b9b495776a67d86 (diff)
tlpmgui 1.61
git-svn-id: svn://tug.org/texlive/trunk@3696 c570f23f-e606-0410-a88d-b1316a301751
Diffstat (limited to 'Master/setuptl/tlpm-i386-linux.pl')
-rwxr-xr-xMaster/setuptl/tlpm-i386-linux.pl9
1 files changed, 5 insertions, 4 deletions
diff --git a/Master/setuptl/tlpm-i386-linux.pl b/Master/setuptl/tlpm-i386-linux.pl
index c226e0eec54..61728fdac46 100755
--- a/Master/setuptl/tlpm-i386-linux.pl
+++ b/Master/setuptl/tlpm-i386-linux.pl
@@ -1,8 +1,8 @@
#!/usr/bin/env perl
# This file belongs to TLPM v2.19, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl
-BEGIN{$tlpm_version="2.19";$tlpm_os="i386-linux"}
+BEGIN{$tlpm_version="2.20";$tlpm_os="i386-linux"}
# the main tlpm script
@@ -116,7 +116,7 @@ sub main
or &is_opt($arg,'H','Help','readme') and return &readme()
or &is_opt($arg,'b','batch') and do {$batch_file = shift @args;$batch_mode = 1}
# or &is_opt($arg,'q','quiet') and do {$quiet_mode = 1}
- or &is_opt($arg,'D','debug') and do {$debug_mode = 1}
+ or &is_opt($arg,'D','debug') and do {&enable_dbg();}
or &rem_opt($arg) and return $error{'wrong_opt'} -> ($arg,'tlpm --help');
}
unless(defined $tl_source){$tl_source = $ENV{'tl_source'}}# ...or remains undefined
@@ -140,7 +140,8 @@ sub main
}
#$quiet_mode = 0;
-$debug_mode = 0;
+&not2log();
+&disable_dbg();
$batch_mode = 0;
$batch_file = '';
@@ -1,8 +1,8 @@
#!/usr/bin/env perl
-# This file belongs to TLPM v2.19, TeX Live Package Manager
+# This file belongs to TLPM v2.20, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl